/**
 * @description: 案件详情
 * @fileName: index
 * @author: 17076
 * @date: 2024/7/1-下午5:06
 * @version: V1.0.0
 **/
import request from '@/utils/request'
import routes from '../gateway-routes'
import axios from 'axios'
import { baseURL, requestTimeout } from '@/config/net.config'
/** 获取模型分析笔录信息 */
export function queryTripletInfo(data) {
  return request({
    url: `${routes.record}/getThreeInfo`,
    method: 'get',
    params: data
  })
}
/** 保存入库 */
export function saveTripletInfo(data) {
  return request({
    url: `${routes.record}/addNeo4j`,
    method: 'post',
    data
  })
}
/** 查询图谱信息 */
export function queryAtlasInfo(data) {
  return request({
    url: `${routes.neo4j}/getNode`,
    method: 'get',
    params: data
  })
}
/** 获取人员列表 */
export function queryUserList(data) {
  return request({
    url: `${routes.modelCase}/getPerson`,
    method: 'get',
    params: data
  })
}
/** 新增人员 */
export function addUser(data) {
  return request({
    url: `${routes.modelCase}/addPerson`,
    method: 'post',
    data
  })
}
/** 上传笔录 */
export function addOrUpdRecords(formData) {
  return axios.request({
    baseURL,
    timeout: requestTimeout,
    url: `${routes.record}/addOrUpdRecords`,
    method: 'post',
    headers: {
      'Content-Type': 'multipart/form-data'
    },
    data: formData
  }).then(response => {
    return Promise.resolve(response.data)
  }).catch(error => {
    return Promise.reject(error)
  })
}
/** 删除笔录 */
export function delRecords(id) {
  return request({
    url: `${routes.record}/delRecords?id=${id}`,
    method: 'post'
  })
}

/** 获取上传笔录列表 */
export function queryRecordList(data, page, size) {
  return request({
    url: `${routes.record}/queryRecords?page=${page}&size=${size}`,
    method: 'post',
    data
  })
}
/** 查询案件详情 */
export function queryCaseDetails(data) {
  return request({
    url: `${routes.record}/queryCaseDetails`,
    method: 'post',
    data
  })
}
/** 获取案件指标详情 */
export function queryIndexDetail(data, page, size) {
  return request({
    url: `${routes.modelCase}/getIndexDetail?page=${page}&size=${size}`,
    method: 'post',
    params: data
  })
}
