/**
 * @description: 案件管理相关
 * @fileName: index
 * @author: 17076
 * @date: 2024/7/2-下午4:46
 * @version: V1.0.0
 **/
import request from '@/utils/request'
import routes from '../gateway-routes'
import axios from 'axios'
import { baseURL, requestTimeout } from '@/config/net.config'
/** 查询案件列表 */
export function queryCaseList(data, page, size) {
  return request({
    url: `${routes.modelCase}/queryList?page=${page}&size=${size}`,
    method: 'post',
    data
  })
}
/** 新增案件信息 */
export function addCaseInfo(data) {
  return request({
    url: `${routes.modelCase}/addOrUpd`,
    method: 'post',
    data
  })
}
/** 删除案件信息 */
export function delCaseInfo(id) {
  return request({
    url: `${routes.modelCase}/del?id=${id}`,
    method: 'post'
  })
}
/** 检验案件编号是否存在 */
export function checkCaseNo(data) {
  return request({
    url: `${routes.modelCase}/checkCaseNo`,
    method: 'get',
    params: data
  })
}
/** 导入案件 */
export function uploadCase(data) {
  return axios.request({
    baseURL,
    timeout: requestTimeout,
    url: `${routes.modelCase}/uploadCase`,
    method: 'post',
    headers: {
      'Content-Type': 'multipart/form-data'
    },
    data
  }).then(response => {
    return Promise.resolve(response.data)
  }).catch(error => {
    return Promise.reject(error)
  })
}
/** 执行模型分析 */
export function executeModelAnalyse(data) {
  return request({
    url: `${routes.model}/analyseCase`,
    method: 'post',
    data
  })
}
