import Vue from 'vue'
import VueRouter from 'vue-router'
import Layout from '@/layouts'
import { publicPath, routerMode } from '@/config'
const originalPush = VueRouter.prototype.push

// 解决报错信息：NavigationDuplicated: Avoided redundant navigation to current location
VueRouter.prototype.push = function push(location) {
  return originalPush.call(this, location).catch(err => err)
}

Vue.use(VueRouter)
export const constantRoutes = [
  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true
  },
  {
    path: '/401',
    name: '401',
    component: () => import('@/views/401'),
    hidden: true
  },
  {
    path: '/404',
    name: '404',
    component: () => import('@/views/404'),
    hidden: true
  },
  {
    path: '/to-pc',
    name: 'ToPc',
    component: () => import('@/views/toPc'),
    hidden: true
  }
]

export const asyncRoutes = [
  {
    path: '/',
    name: 'home',
    component: Layout,
    redirect: '/index',
    authKey: 'back_home',
    meta: { title: '首页' },
    children: [
      {
        path: '/index',
        name: 'Index',
        component: () => import('@/views/index/index.vue'),
        meta: { title: '首页', affix: false }
      }
    ]
  },
  {
    path: '/case',
    name: 'Case',
    component: Layout,
    meta: { title: '案件管理' },
    children: [
      {
        path: '/case-management',
        name: 'CaseManagement',
        component: () => import('@/views/caseManagement/index.vue'),
        meta: { title: '案件管理', affix: false }
      }
    ]
  },
  {
    path: '/rule',
    name: 'Rule',
    component: Layout,
    meta: { title: '规则配置' },
    children: [
      {
        path: '/index-rule',
        name: 'IndexRule',
        component: () => import('@/views/ruleEngine/indexRule/index.vue'),
        meta: { title: '指标规则', affix: false, subtitle: '大模型分析提取案件信息的指标项' }
      },
      {
        path: '/model-rule',
        name: 'ModelRule',
        component: () => import('@/views/ruleEngine/modelRule/index.vue'),
        meta: { title: '模型规则', affix: false, subtitle: '平台大模型已具备的分析多类型案件能力' }
      },
      {
        path: '/atomic-rule',
        name: 'AtomicRule',
        component: () => import('@/views/ruleEngine/atomicIndex/index.vue'),
        meta: { title: '原子指标', affix: false, subtitle: '提取案件信息的指标项无法在拆分的指标' }
      }
    ]
  },
  {
    path: '/system',
    name: 'System',
    component: Layout,
    meta: { title: '系统设置' },
    children: [
      {
        path: '/account-management',
        name: 'AccountManagement',
        component: () => import('@/views/system/accountManagement/index.vue'),
        meta: { title: '账号管理', affix: false }
      },
      {
        path: '/config-management',
        name: 'ConfigManagement',
        component: () => import('@/views/system/configManagement/index.vue'),
        meta: { title: '配置管理', affix: false }
      }
    ]
  },
  {
    path: '/case2',
    name: 'Case2',
    component: Layout,
    meta: { title: '案件' },
    hidden: true,
    children: [
      {
        path: '/case-details/:id/:caseName/',
        name: 'CaseDetails',
        component: () => import('@/views/caseDetails/index.vue'),
        meta: { title: '案件详情', affix: true }
      }
    ]
  },
  {
    path: '/prompt',
    name: 'Prompt',
    component: Layout,
    meta: { title: '提示词模板' },
    children: [
      {
        path: '/prompt-management',
        name: 'PromptManagement',
        component: () => import('@/views/promptManagement/index.vue'),
        meta: { title: '提示词模板', affix: false }
      }
    ]
  },
  {
    path: '*',
    redirect: '/404',
    hidden: true
  }
]

const router = new VueRouter({
  base: publicPath,
  mode: routerMode,
  scrollBehavior: () => ({
    y: 0
  }),
  routes: constantRoutes
})

export function resetRouter() {
  location.reload()
}

export default router
