import { asyncRoutes, constantRoutes } from '@/router'
import { getRouterList } from '@/api/base/user'
import { convertPermission, convertRouter, filterAsyncRoutes } from '@/utils/handleRoutes'

const state = () => ({
  routes: [],
  auths: [],
  partialRoutes: []
})
const getters = {
  routes: (state) => state.routes,
  auths: (state) => state.auths,
  partialRoutes: (state) => state.partialRoutes
}
const mutations = {
  setRoutes(state, routes) {
    state.routes = constantRoutes.concat(routes)
  },
  setAllRoutes(state, routes) {
    state.routes = constantRoutes.concat(routes)
  },
  setBtnPer(state, auths) {
    state.auths = auths
  },
  setPartialRoutes(state, routes) {
    state.partialRoutes = constantRoutes.concat(routes)
  }
}
const actions = {
  async setRoutes({ commit }, permissions) {
    // 开源版只过滤动态路由permissions，admin不再默认拥有全部权限
    const finallyAsyncRoutes = await filterAsyncRoutes(
      [...asyncRoutes],
      permissions
    )
    commit('setRoutes', finallyAsyncRoutes)
    return finallyAsyncRoutes
  },
  async setAllRoutes({ commit }) {
    const { data } = await getRouterList()
    data.push({ path: '*', redirect: '/404', hidden: true })
    const accessRoutes = convertRouter(JSON.parse(JSON.stringify(data)))
    const temBtn = convertPermission(data)
    commit('setAllRoutes', accessRoutes)
    commit('setBtnPer', temBtn)
    return accessRoutes
  },
  setPartialRoutes({ commit }, accessRoutes) {
    commit('setPartialRoutes', accessRoutes)
    return accessRoutes
  }
}
export default { state, getters, mutations, actions }
