/**
 * @author jc
 * @description 所有全局配置的状态管理，如无必要请勿修改
 */

import defaultSettings from '@/config'

const { tabsBar, logo, layout, header, themeBar } = defaultSettings
const theme =
  JSON.parse(localStorage.getItem('base-web-theme')) || ''
const state = () => ({
  tabsBar: theme.tabsBar || tabsBar,
  logo,
  collapse: true,
  tagsView: theme.tagsView || true,
  header: theme?.header || header,
  device: 'desktop',
  layout: theme.layout || layout,
  themeBar
})
const getters = {
  device: (state) => state.device,
  header: (state) => state.header,
  logo: (state) => state.logo,
  tagsView: (state) => state.tagsView,
  tabsBar: (state) => state.tabsBar,
  themeBar: (state) => state.themeBar,
  layout: (state) => state.layout
}
const mutations = {
  changeLayout: (state, layout) => {
    if (layout) state.layout = layout
  },
  changeHeader: (state, header) => {
    if (header) state.header = header
  },
  changeTagsView: (state, tagsView) => {
    if (tagsView) state.tagsView = tagsView
  },
  changeTabsBar: (state, tabsBar) => {
    if (tabsBar) state.tabsBar = tabsBar
  },
  toggleDevice: (state, device) => {
    state.device = device
  }
}
const actions = {
  changeLayout({ commit }, layout) {
    commit('changeLayout', layout)
  },
  changeHeader({ commit }, header) {
    commit('changeHeader', header)
  },
  changeTagsView({ commit }, tagsView) {
    commit('changeTagsView', tagsView)
  },
  changeTabsBar({ commit }, tabsBar) {
    commit('changeTabsBar', tabsBar)
  },
  toggleDevice({ commit }, device) {
    commit('toggleDevice', device)
  }
}
export default { state, getters, mutations, actions }
